@@ -1,11 +1,10 @@
 ;(function($) {
-  window.convos = window.convos || {};
+  window.convos = window.convos || {}
 
   convos.nicks = {
     list: [],
     init: function($e) {
       if (!$e.data('to_current')) return;
-      if (!convos.nicks.list.length && $('.messages li.message').length > 1) $e.data('to_current', false); // only show in conversation on manual "/list"
       $('form.sidebar ul li.nick.status').remove();
       $e.find('[data-nick]').each(function() { convos.nicks.joined($(this).data('to_current', true)); });
     },
@@ -46,8 +45,6 @@
         convos.nicks.list.push(nick);
         $ul.append(markup);
       }
-
-      convos.nicks.updateNumberOfNicks();
     },
     quit: function($e) {
       if ($e.data('network') != convos.current.network) return;
@@ -55,21 +52,15 @@
       $e.data('to_current', !!$.grep(convos.nicks.list, function(n, i) { return n == nick; }).length);
       convos.nicks.list = $.grep(convos.nicks.list, function(n, i) { return n != nick; });
       $('form.sidebar a[href="cmd:///query ' + nick + '"]').parent().remove();
-      convos.nicks.updateNumberOfNicks();
     },
     parted: function($e) {
       if (!$e.data('to_current')) return;
       var nick = $e.data('nick');
       convos.nicks.list = $.grep(convos.nicks.list, function(n, i) { return n != nick; });
       $('form.sidebar a[href="cmd:///query ' + nick + '"]').parent().remove();
-      convos.nicks.updateNumberOfNicks();
     },
     reset: function() {
       convos.nicks.list = [];
-      convos.nicks.updateNumberOfNicks();
-    },
-    updateNumberOfNicks: function() {
-      $('form.sidebar ul li.participants span').text(convos.nicks.list.length);
     }
   };
 })(jQuery);
