@@ -1,4 +1,6 @@
 ;(function($) {
+  var disable_focus = /(iPad|iPhone|iPod)/g.test(navigator.userAgent);
+
   $.fn.hideSidebar = function() {
     $('.sidebar-trigger-active').trigger('tap');
   };
@@ -23,18 +25,18 @@
       if ($a.hasClass('sidebar-trigger-active')) {
         if (e.originalEvent && e.originalEvent.type == 'focus') return false;
         $a.removeClass('active sidebar-trigger-active');
-        $t.removeClass('active').css({ 'z-index': 1000 }).animate({ right: -($t.outerWidth() + 20) }, 100); // +20 to hide shadow
-        if (!$('.sidebar-trigger-active').length && !navigator.is_touch_device) convos.input.focus();
+        $t.removeClass('active').css({ 'z-index': 900 }).animate({ right: -($t.outerWidth() + 20) }, 100); // +20 to hide shadow
+        if (!$('.sidebar-trigger-active').length && !disable_focus) convos.input.focus();
         return false;
       }
 
       $hide = $('.sidebar-trigger-active').trigger('tap');
       if ($t.is(':animated')) return; // supposed to just hide, not show
       $a.addClass('active sidebar-trigger-active');
-      $t.addClass('active').css({ 'z-index': 999, right: $hide.length ? 0 : -$t.outerWidth() }).show().animate({ right: 0 }, 150);
+      $t.addClass('active').css({ 'z-index': 901, right: $hide.length ? 0 : -$t.outerWidth() }).show().animate({ right: 0 }, 150);
       $t.trigger('show');
 
-      if (navigator.is_touch_device) {
+      if (disable_focus) {
         $t.find('select').each(function() { var s = this.selectize; if(s) setTimeout(function() { s.show(); }, 50); });
       }
       else {
